.. _cli-show-concept-doi:

===========================
``toasty show concept-doi``
===========================

The ``show concept-doi`` command prints the `concept DOI`_ associated with
the Toasty software package.

.. _concept DOI: https://help.zenodo.org/

Usage
=====

.. code-block:: shell

   toasty show concept-doi

Prints out Toasty’s concept DOI.

Notes
=====

A `concept DOI`_ is a unique identifier used to associate multiple releases of a
software package. If you are trying to preserve information about your usage of
the Toasty software, you should almost certainly prefer the
:ref:`cli-show-version-doi` command.


See Also
========

- :ref:`cli-show-version-doi`
